@@ -70,6 +70,7 @@ archive_read_vtable(void)
 	if (!inited) {
 		av.archive_finish = _archive_read_finish;
 		av.archive_close = _archive_read_close;
+		inited = 1;
 	}
 	return (&av);
 }
@@ -169,7 +170,6 @@ archive_read_set_filter_options(struct archive *_a, const char *s)
 	a = (struct archive_read *)_a;
 	__archive_check_magic(&a->archive, ARCHIVE_READ_MAGIC,
 	    ARCHIVE_STATE_NEW, "archive_read_set_filter_options");
-	filter = a->filter;
 	len = 0;
 	for (filter = a->filter; filter != NULL; filter = filter->upstream) {
 		bidder = filter->bidder;
@@ -474,7 +474,7 @@ choose_format(struct archive_read *a)
 	best_bid = -1;
 	best_bid_slot = -1;
 
-	/* Set up a->format and a->pformat_data for convenience of bidders. */
+	/* Set up a->format for convenience of bidders. */
 	a->format = &(a->formats[0]);
 	for (i = 0; i < slots; i++, a->format++) {
 		if (a->format->bid) {
@@ -729,7 +729,7 @@ archive_read_data_block(struct archive *_a,
 	if (a->format->read_data == NULL) {
 		archive_set_error(&a->archive, ARCHIVE_ERRNO_PROGRAMMER,
 		    "Internal error: "
-		    "No format_read_data_block function registered");
+		    "No format->read_data function registered");
 		return (ARCHIVE_FATAL);
 	}
 
@@ -959,7 +959,7 @@ __archive_read_get_bidder(struct archive_read *a)
  * possible.
  *
  * Mostly, this code returns pointers directly into the block of data
- * provided by the client_read routine.  It can do this unless the
+ * provided by the client's read routine.  It can do this unless the
  * request would split across blocks.  In that case, we have to copy
  * into an internal buffer to combine reads.
  */
@@ -1229,10 +1229,8 @@ __archive_read_filter_skip(struct archive_read_filter *filter, int64_t request)
 	 * have to use ordinary reads to finish out the request.
 	 */
 	while (request > 0) {
-		const void* dummy_buffer;
 		ssize_t bytes_read;
-		dummy_buffer = __archive_read_ahead(filter->archive,
-		    1, &bytes_read);
+		(void)__archive_read_ahead(filter->archive, 1, &bytes_read);
 		if (bytes_read < 0)
 			return (bytes_read);
 		if (bytes_read == 0) {
