@@ -999,12 +999,11 @@ static const char *long_help_msg =
 	"  --cachedir <directory>  Cache directory\n"
 	"  -v    Verbose\n"
 	"  -w    Interactive\n"
-	"Create: %p -c [options] [<file> | <dir> | @<archive> | -C <dir> ]\n"
+	"Create: %p -c [options] [<file> | <dir> | @@<archive> | -C <dir>] ...\n"
 	"  <file>, <dir>  add these items to archive\n"
 	"  --exclude <pattern>  Skip files that match pattern\n"
 	"  -C <dir>  Change to <dir> before processing remaining files\n"
-	"  @<filename>  Add entries from archive <filename>\n"
-	"  @@ <archive>  Add entries from tarsnap archive <archive>\n"
+	"  @@<archive>  Add entries from tarsnap archive <archive>\n"
 	"List: %p -t [options] [<patterns>]\n"
 	"  <patterns>  If specified, list only entries that match\n"
 	"Extract: %p -x [options] [<patterns>]\n"
